#ifndef NT2_INCLUDE_CONSTANTS_FIVE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FIVE_HPP_INCLUDED

#include <nt2/constant/include/constants/five.hpp>

#endif
